@@ -7,7 +7,8 @@ def _readuntil(stream: BytesIO, pattern: bytes):
     matched = 0
     buffer = bytes()
     while matched < len(pattern):
-        if (char := stream.read(1))[0] == pattern[matched]:
+        char = stream.read(1)
+        if char[0] == pattern[matched]:
             matched += 1
         else:
             matched = 0
